@@ -1,3 +1,3 @@
 __version__ = "0.1.0"
 from .extractor import *
-from .initial import initial
+from .initial import *
